/// Log option configuration.
class LogOption {
  const LogOption({
    this.projectName,
    this.mode,
    this.isEnable,
    this.language,
    this.colorTheme,
    this.decorator,
    this.splitDecorator,
  });

  ///  Project name. default: 'idkit_log'
  final String? projectName;

  /// Whether to enable log output.default: true
  final bool? isEnable;

  /// Log output language type. default: Language.en
  final Language? language;

  /// Log output color theme.default: ColorTheme.blue
  final ColorTheme? colorTheme;

  /// Log output decorator. default: '*'
  final String? decorator;

  /// Log output split decorator. default: '-'
  final String? splitDecorator;

  /// Log output mode.
  final LogMode? mode;

  /// Merge attributes.
  LogOption copy(LogOption? option) {
    return LogOption(
      projectName: option?.projectName ?? projectName ?? 'idkit_log',
      isEnable: option?.isEnable ?? isEnable ?? true,
      language: option?.language ?? language ?? Language.en,
      colorTheme: option?.colorTheme ?? colorTheme ?? ColorTheme.blue,
      decorator: option?.decorator ?? decorator ?? '*',
      splitDecorator: option?.splitDecorator ?? splitDecorator ?? '-',
      mode: option?.mode ?? mode ?? LogMode.normal,
    );
  }
}

/// Language
enum Language {
  en,
  zh,
}

/// Color theme
enum ColorTheme {
  red,
  yellow,
  green,
  blue,
  cyan,
  white,
  black,
}

/// Log output mode
enum LogMode {
  normal,
  brief,
  full,
}
