import 'package:flutter/material.dart';
import 'package:idkit/idkit.dart';

class IDKitSlider {
  /// Slide track widget.
  /// All parameters can be viewed in [CustomSingleSlider].
  static CustomSingleSlider slider({
    Key? key,
    double initValue = 0,
    double maxValue = 1,
    double minValue = 0,
    double thumbSize = 6,
    Color thumbColor = Colors.blue,
    Duration thumbAnimationDuration = const Duration(milliseconds: 200),
    double trackIndent = 3,
    double trackHeight = 3,
    Color trackColor = Colors.grey,
    Color trackActiveColor = Colors.blue,
    List<Color>? trackActiveGradientColors,
    List<double>? trackActiveGradientStops,
    AlignmentGeometry trackActiveGradientBegin = Alignment.centerLeft,
    AlignmentGeometry trackActiveGradientEnd = Alignment.centerRight,
    TileMode trackActiveGradientTileMode = TileMode.clamp,
    bool floatingMark = true,
    double floatingMarkWidth = 1,
    double floatingMarkIndent = 3,
    Color floatingMarkColor = Colors.blue,
    void Function(double)? sliderValueMethod,
  }) =>
      CustomSingleSlider(
        key: key,
        initValue: initValue,
        maxValue: maxValue,
        minValue: minValue,
        thumbSize: thumbSize,
        thumbColor: thumbColor,
        thumbAnimationDuration: thumbAnimationDuration,
        trackIndent: trackIndent,
        trackHeight: trackHeight,
        trackColor: trackColor,
        trackActiveColor: trackActiveColor,
        trackActiveGradientColors: trackActiveGradientColors,
        trackActiveGradientStops: trackActiveGradientStops,
        trackActiveGradientBegin: trackActiveGradientBegin,
        trackActiveGradientEnd: trackActiveGradientEnd,
        trackActiveGradientTileMode: trackActiveGradientTileMode,
        floatingMark: floatingMark,
        floatingMarkWidth: floatingMarkWidth,
        floatingMarkIndent: floatingMarkIndent,
        floatingMarkColor: floatingMarkColor,
        sliderValueMethod: sliderValueMethod,
      );

  /// Bilateral sliding track widget.
  /// All parameters can be viewed in [CustomBilateralSilder].
  static CustomBilateralSilder bilateralSlider({
    Key? key,
    double initValue = 0,
    double maxValue = 1,
    double minValue = -1,
    double thumbSize = 6,
    Color thumbColor = Colors.blue,
    Duration thumbAnimationDuration = const Duration(milliseconds: 200),
    double trackIndent = 3,
    double trackHeight = 3,
    Color trackColor = Colors.grey,
    Color trackActiveColor = Colors.blue,
    List<Color>? trackActiveGradientColors,
    List<double>? trackActiveGradientStops,
    AlignmentGeometry trackActiveGradientBegin = Alignment.centerLeft,
    AlignmentGeometry trackActiveGradientEnd = Alignment.centerRight,
    TileMode trackActiveGradientTileMode = TileMode.clamp,
    bool floatingMark = true,
    double floatingMarkWidth = 1,
    double floatingMarkIndent = 3,
    Color floatingMarkColor = Colors.blue,
    void Function(double)? sliderValueMethod,
  }) =>
      CustomBilateralSilder(
        key: key,
        initValue: initValue,
        maxValue: maxValue,
        minValue: minValue,
        thumbSize: thumbSize,
        thumbColor: thumbColor,
        thumbAnimationDuration: thumbAnimationDuration,
        trackIndent: trackIndent,
        trackHeight: trackHeight,
        trackColor: trackColor,
        trackActiveColor: trackActiveColor,
        trackActiveGradientColors: trackActiveGradientColors,
        trackActiveGradientStops: trackActiveGradientStops,
        trackActiveGradientBegin: trackActiveGradientBegin,
        trackActiveGradientEnd: trackActiveGradientEnd,
        trackActiveGradientTileMode: trackActiveGradientTileMode,
        floatingMark: floatingMark,
        floatingMarkWidth: floatingMarkWidth,
        floatingMarkIndent: floatingMarkIndent,
        floatingMarkColor: floatingMarkColor,
        sliderValueMethod: sliderValueMethod,
      );

  /// Range Slider Widget.
  /// All parameters can be viewed in [CustomRangeSlider].
  static CustomRangeSlider rangeSlider({
    Key? key,
    double initLeftValue = 0,
    double initRightValue = 1,
    double maxValue = 1,
    double minValue = 0,
    double thumbSize = 6,
    Color thumbColor = Colors.blue,
    Duration thumbAnimationDuration = const Duration(milliseconds: 200),
    double trackIndent = 3,
    double trackHeight = 3,
    Color trackColor = Colors.grey,
    Color trackActiveColor = Colors.blue,
    List<Color>? trackActiveGradientColors,
    List<double>? trackActiveGradientStops,
    AlignmentGeometry trackActiveGradientBegin = Alignment.centerLeft,
    AlignmentGeometry trackActiveGradientEnd = Alignment.centerRight,
    TileMode trackActiveGradientTileMode = TileMode.clamp,
    bool floatingMark = true,
    double floatingMarkWidth = 1,
    double floatingMarkIndent = 3,
    Color floatingMarkColor = Colors.blue,
    void Function(double, double)? sliderValueMethod,
  }) =>
      CustomRangeSlider(
        key: key,
        initLeftValue: initLeftValue,
        initRightValue: initRightValue,
        maxValue: maxValue,
        minValue: minValue,
        thumbSize: thumbSize,
        thumbColor: thumbColor,
        thumbAnimationDuration: thumbAnimationDuration,
        trackIndent: trackIndent,
        trackHeight: trackHeight,
        trackColor: trackColor,
        trackActiveColor: trackActiveColor,
        trackActiveGradientColors: trackActiveGradientColors,
        trackActiveGradientStops: trackActiveGradientStops,
        trackActiveGradientBegin: trackActiveGradientBegin,
        trackActiveGradientEnd: trackActiveGradientEnd,
        trackActiveGradientTileMode: trackActiveGradientTileMode,
        floatingMark: floatingMark,
        floatingMarkWidth: floatingMarkWidth,
        floatingMarkIndent: floatingMarkIndent,
        floatingMarkColor: floatingMarkColor,
        sliderValueMethod: sliderValueMethod,
      );
}

/// Subscribers to the active track of the scope slide track.
class TrackRangeInfo {
  const TrackRangeInfo({this.leftLocation = 0, this.rightLocation = 0});
  final double leftLocation;
  final double rightLocation;
  double get distance => rightLocation - leftLocation;
}

/// The information object of the floating block.
class FloatingMarkInfo {
  const FloatingMarkInfo({
    this.position = 0,
    this.state = false,
  });
  final double position;
  final bool state;
}
